@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -55,7 +55,7 @@
 
 /* valarm.cpp/h contains functions to convert reminder <-> valarm */
 
-HRESULT HrParseReminder(LONG lRemindBefore, icalcomponent **lppAlarm);
+HRESULT HrParseReminder(LONG lRemindBefore, time_t ttReminderTime, bool bTask, icalcomponent **lppAlarm);
 HRESULT HrParseVAlarm(icalcomponent *lpComp, LONG *lpulRemindBefore, time_t *lpttReminderTime, bool *lpbReminderSet);
 
 #endif
