@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -68,19 +68,7 @@ public:
 	ECVMIMESender(ECLogger *newlpLogger, std::string strSMTPHost, int port);
 	virtual	~ECVMIMESender();
 
-#ifdef DEBUG
-	HRESULT printMail(vmime::message *lpVMMessage);
-#endif
 	HRESULT sendMail(LPADRBOOK lpAdrBook, LPMESSAGE lpMessage, vmime::ref<vmime::message> vmMessage, bool bAllowEveryone);
 };
 
-class ECScreenSender : public ECSender
-{
-public:
-	ECScreenSender(ECLogger *newlpLogger);
-	virtual	~ECScreenSender();
-
-	HRESULT sendMail(vmime::ref<vmime::message> vmMessage);
-};
-
 #endif
