@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -50,13 +50,8 @@
 #ifndef ECLIBSYNC_INCLUDED
 #define ECLIBSYNC_INCLUDED
 
-#if defined(WIN32) && !defined(SWIG)
-	#ifdef ZARAFALIBSYNC_EXPORTS
-		#define ECLIBSYNC_API __declspec(dllexport)
-	#else
-		#define ECLIBSYNC_API __declspec(dllimport)
-	#endif
-#else
+
+#ifndef ECLIBSYNC_API
 	#define ECLIBSYNC_API
 #endif
 
