@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -62,6 +62,7 @@ struct configsetting_t {
 #define CONFIGSETTING_UNUSED		0x0004
 #define CONFIGSETTING_NONEMPTY		0x0008
 #define CONFIGSETTING_EXACT			0x0010
+#define CONFIGSETTING_SIZE			0x0020
 	unsigned short ulGroup;
 #define CONFIGGROUP_PROPMAP			0x0001
 };
@@ -83,6 +84,7 @@ public:
 
 	virtual bool	LoadSettings(const char *szFilename) = 0;
 	virtual bool	LoadSettings(const wchar_t *szFilename);
+	virtual bool    ParseParams(int argc, char *argv[], int *lpargidx) = 0;
 	virtual const char*	GetSettingsPath() = 0;
 	virtual bool	ReloadSettings() = 0;
 
@@ -94,6 +96,7 @@ public:
 	virtual wchar_t* GetSettingW(const char *szName, wchar_t *equal, wchar_t *other) = 0;
 
 	virtual std::list<configsetting_t> GetSettingGroup(unsigned int ulGroup) = 0;
+	virtual std::list<configsetting_t> GetAllSettings() = 0;
 
 	virtual bool	HasWarnings() = 0;
 	virtual std::list<std::string>* GetWarnings() = 0;
