@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -212,6 +212,19 @@
 #define METHODSTR_HELPER1(_method)	METHODSTR_HELPER2(_method)
 #define METHODSTR_HELPER2(_method)	#_method
 
+#define DEF_ULONGMETHOD(_trace, _class, _iface, _method, ...)														\
+ULONG __stdcall CLASSMETHOD(_class, CLASSMETHOD(XCLASS(_iface), _method))(ARGLIST(__VA_ARGS__))	{			\
+	_trace(TRACE_ENTRY, METHODSTR(_iface, _method), FORMAT_ARGS(__VA_ARGS__), PRINT_ARGS_IN( __VA_ARGS__));			\
+	ULONG ul = 0;																						\
+	try {																										\
+		METHOD_PROLOGUE_(_class, _iface);																		\
+		ul = pThis->_method(ARGS(__VA_ARGS__));																	\
+	} catch (const std::bad_alloc &) {																			\
+		ul = -1;																			\
+	}																											\
+	_trace(TRACE_RETURN, METHODSTR(_iface, _method), "SUCCESS: " FORMAT_ARGS(__VA_ARGS__), PRINT_ARGS_OUT(__VA_ARGS__));	\
+	return ul;																									\
+}
 
 #define DEF_HRMETHOD(_trace, _class, _iface, _method, ...)														\
 HRESULT __stdcall CLASSMETHOD(_class, CLASSMETHOD(XCLASS(_iface), _method))(ARGLIST(__VA_ARGS__))	{			\
@@ -230,6 +243,40 @@ HRESULT __stdcall CLASSMETHOD(_class, CLASSMETHOD(XCLASS(_iface), _method))(ARGL
 	return hr;																									\
 }
 
+#define DEF_HRMETHOD_EX(_trace, _class, _iface, _extra_fmt, _extra_arg, _method, ...)														\
+HRESULT __stdcall CLASSMETHOD(_class, CLASSMETHOD(XCLASS(_iface), _method))(ARGLIST(__VA_ARGS__))	{			\
+	METHOD_PROLOGUE_(_class, _iface);																		\
+	_trace(TRACE_ENTRY, METHODSTR(_iface, _method), _extra_fmt ", " FORMAT_ARGS(__VA_ARGS__), _extra_arg, PRINT_ARGS_IN( __VA_ARGS__));			\
+	HRESULT	hr = hrSuccess;																						\
+	try {																										\
+		hr = pThis->_method(ARGS(__VA_ARGS__));																	\
+	} catch (const std::bad_alloc &) {																			\
+		hr = MAPI_E_NOT_ENOUGH_MEMORY;																			\
+	}																											\
+	if (FAILED(hr))																								\
+		_trace(TRACE_RETURN, METHODSTR(_iface, _method), "FAILED: %s " _extra_fmt, GetMAPIErrorDescription(hr).c_str(), _extra_arg);	\
+	else																										\
+		_trace(TRACE_RETURN, METHODSTR(_iface, _method), "SUCCESS: " _extra_fmt ", " FORMAT_ARGS(__VA_ARGS__), _extra_arg, PRINT_ARGS_OUT(__VA_ARGS__));	\
+	return hr;																									\
+}
+
+#define DEF_HRMETHOD_EX2(_trace, _class, _iface, _extra_fmt, _extra_arg1, _extra_arg2, _method, ...)														\
+HRESULT __stdcall CLASSMETHOD(_class, CLASSMETHOD(XCLASS(_iface), _method))(ARGLIST(__VA_ARGS__))	{			\
+	METHOD_PROLOGUE_(_class, _iface);																		\
+	_trace(TRACE_ENTRY, METHODSTR(_iface, _method), _extra_fmt ", " FORMAT_ARGS(__VA_ARGS__), _extra_arg1, _extra_arg2, PRINT_ARGS_IN( __VA_ARGS__));			\
+	HRESULT	hr = hrSuccess;																						\
+	try {																										\
+		hr = pThis->_method(ARGS(__VA_ARGS__));																	\
+	} catch (const std::bad_alloc &) {																			\
+		hr = MAPI_E_NOT_ENOUGH_MEMORY;																			\
+	}																											\
+	if (FAILED(hr))																								\
+		_trace(TRACE_RETURN, METHODSTR(_iface, _method), "FAILED: %s " _extra_fmt, GetMAPIErrorDescription(hr).c_str(), _extra_arg1, _extra_arg2);	\
+	else																										\
+		_trace(TRACE_RETURN, METHODSTR(_iface, _method), "SUCCESS: " _extra_fmt ", " FORMAT_ARGS(__VA_ARGS__), _extra_arg1, _extra_arg2, PRINT_ARGS_OUT(__VA_ARGS__));	\
+	return hr;																									\
+}
+
 #define DEF_HRMETHOD_FORWARD(_trace, _class, _iface, _method, _member, ...)														\
 HRESULT __stdcall CLASSMETHOD(_class, _method)(ARGLIST(__VA_ARGS__))	{			\
 	_trace(TRACE_ENTRY, METHODSTR(_iface, _method), FORMAT_ARGS(__VA_ARGS__), PRINT_ARGS_IN( __VA_ARGS__));			\
@@ -246,3 +293,10 @@ HRESULT __stdcall CLASSMETHOD(_class, _method)(ARGLIST(__VA_ARGS__))	{			\
 	return hr;																									\
 }
 
+#define DEF_HRMETHOD_NOSUPPORT(_trace, _class, _iface, _method, ...)														\
+HRESULT __stdcall CLASSMETHOD(_class, CLASSMETHOD(XCLASS(_iface), _method))(ARGLIST(__VA_ARGS__))	{			\
+	_trace(TRACE_ENTRY, METHODSTR(_iface, _method), FORMAT_ARGS(__VA_ARGS__), PRINT_ARGS_IN( __VA_ARGS__));			\
+	HRESULT	hr = MAPI_E_NO_SUPPORT;																						\
+	_trace(TRACE_RETURN, METHODSTR(_iface, _method), "FAILED: %s", GetMAPIErrorDescription(hr).c_str());	\
+	return hr;																									\
+}
