@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -83,6 +83,8 @@ public:
 	void setThreadCount(unsigned ulThreadCount, bool bWait = false);
 	
 	struct timeval queueAge() const;
+
+	bool waitForAllTasks(time_t timeout) const;
 	
 private:	// methods
 	virtual bool getNextTask(STaskInfo *lpsTaskInfo);
@@ -100,6 +102,7 @@ private:	// members
 	mutable pthread_mutex_t	m_hMutex;
 	pthread_cond_t			m_hCondition;
 	pthread_cond_t			m_hCondTerminated;
+	mutable pthread_cond_t	m_hCondTaskDone;
 
 private:
 	ECThreadPool(const ECThreadPool &);
@@ -201,20 +204,26 @@ class ECWaitableTask : public ECTask
 public:
 	static const unsigned WAIT_INFINITE = (unsigned)-1;
 	
+	enum State {
+		Idle = 1,
+		Running = 2,
+		Done = 4
+	};
+	
 public:
 	virtual ~ECWaitableTask();
 	virtual void execute();
 	
 	bool done() const;
-	bool wait(unsigned timeout = WAIT_INFINITE) const;
+	bool wait(unsigned timeout = WAIT_INFINITE, unsigned waitMask = Done) const;
 	
 protected:
 	ECWaitableTask();
-	
+
 private:
 	mutable pthread_mutex_t	m_hMutex;
 	mutable pthread_cond_t	m_hCondition;
-	bool					m_bDone;
+	State					m_state;
 };
 
 /**
@@ -222,7 +231,7 @@ private:
  * @retval true when executed, false otherwise.
  */
 inline bool ECWaitableTask::done() const {
-	return m_bDone;
+	return m_state == Done;
 }
 
 
