@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -50,10 +50,13 @@
 #ifndef IECEXPORTCHANGES_H
 #define IECEXPORTCHANGES_H
 
+#include <edkmdb.h>
+
 class ECLogger;
 
-class IECExportChanges : public IUnknown{
+class IECExportChanges : public IExchangeExportChanges {
 public:
+	virtual HRESULT __stdcall ConfigSelective(ULONG ulPropTag, LPENTRYLIST lpEntries, LPENTRYLIST lpParents, ULONG ulFlags, LPUNKNOWN lpCollector, LPSPropTagArray lpIncludeProps, LPSPropTagArray lpExcludeProps, ULONG ulBufferSize) = 0;
 	virtual HRESULT __stdcall GetChangeCount(ULONG *lpcChanges) = 0;
 	virtual HRESULT __stdcall SetMessageInterface(REFIID refiid) = 0;
 	virtual HRESULT __stdcall SetLogger(ECLogger *lpLogger) = 0;
