@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -67,7 +67,11 @@ void TraceRelease(char *format, ...);
 
 #define TRACE_RELEASE	TraceRelease
 
-#ifdef DEBUG
+#if !defined(WITH_TRACING) && defined(DEBUG)
+# define WITH_TRACING
+#endif
+
+#ifdef WITH_TRACING
 #define TRACE_MAPI		TraceMapi
 #define TRACE_MAPILIB	TraceMapiLib
 #define TRACE_ECMAPI	TraceECMapi
