@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -91,7 +91,7 @@ public:
 	static LONG		FindPropInArray(LPSPropTagArray lpPropTags, ULONG ulPropTag);
 
 	static HRESULT HrStreamToString(IStream *sInput, std::string &strOutput);
-	static HRESULT HrStreamToWString(IStream *sInput, std::wstring &strWOutput);
+	static HRESULT HrStreamToString(IStream *sInput, std::wstring &strWOutput);
 
 	static HRESULT HrConvertStreamToWString(IStream *sInput, ULONG ulCodepage, std::wstring *wstrOutput);
 
@@ -104,7 +104,11 @@ public:
 	static HRESULT	HrHtmlToRtf(IStream *html, IStream *rtf, unsigned int ulCodepage);
 	static HRESULT	HrHtmlToRtf(const WCHAR *lpwHTML, std::string& strRTF);
 
+	static ULONG GetBestBody(LPSPropValue lpBody, LPSPropValue lpHtml, LPSPropValue lpRtfCompressed, LPSPropValue lpRtfInSync, ULONG ulFlags);
 	static ULONG GetBestBody(IMAPIProp *lpPropObj, ULONG ulFlags);
+	static ULONG GetBestBody(LPSPropValue lpPropArray, ULONG cValues, ULONG ulFlags);
+
+	static bool IsBodyProp(ULONG ulPropTag);
 
 	static HRESULT HrMAPIErrorToText(HRESULT hr, LPTSTR *lppszError, void *lpBase = NULL);
 
@@ -112,6 +116,7 @@ public:
 
 	static HRESULT bin2hex(ULONG inLength, LPBYTE input, char **output, void *parent = NULL);
 	static HRESULT hex2bin(const char *input, size_t len, ULONG *outLength, LPBYTE *output, void *parent = NULL);
+	static HRESULT hex2bin(const char *input, size_t len, LPBYTE output);
 
 	template <size_t N>
 	static bool StrCaseCompare(const WCHAR *lpString, const WCHAR (&lpFind)[N], size_t pos = 0) {
