@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -47,9 +47,12 @@
  * 
  */
 
+#ifndef __OpenBSD__
 #ifndef __CHARSET_UTIL_H
 #define __CHARSET_UTIL_H
 
 bool forceUTF8Locale(bool bOutput, std::string *lpstrLastSetLocale = NULL);
+locale_t createUTF8Locale();
 
 #endif
+#endif /* !OpenBSD */
