@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -500,6 +500,10 @@
 #define PR_7BIT_DISPLAY_NAME_W PROP_TAG(PT_UNICODE, PROP_ID(PR_7BIT_DISPLAY_NAME))
 #endif
 
+#ifndef PR_ASSOCIATED
+#define PR_ASSOCIATED					PROP_TAG(PT_BOOLEAN, 0x67AA)
+#endif
+
 #define PR_PACKED_NAME_PROPS		PROP_TAG(PT_BINARY, 0x361C)
 
 #define PR_IPM_APPOINTMENT_ENTRYID	PROP_TAG(PT_BINARY, 0x36D0)
@@ -804,13 +808,7 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 #define PR_DECLINE_CONFLICTING_MEETING_REQUESTS	PROP_TAG(PT_BOOLEAN, 0x686f)
 #define PR_DECLINE_RECURRING_MEETING_REQUESTS	PROP_TAG(PT_BOOLEAN, 0x686e)
 
-#ifndef PR_FREEBUSY_ENTRYIDS
-#define PR_FREEBUSY_ENTRYIDS PROP_TAG(PT_MV_BINARY, 0x36e4)
-#endif
-
-#ifndef PR_FREEBUSY_NUM_MONTHS
-#define PR_FREEBUSY_NUM_MONTHS PROP_TAG(PT_LONG, 0x6841)
-#endif
+#define PR_SCHDINFO_RESOURCE_TYPE	PROP_TAG(PT_LONG, 0x6841)
 
 // Notify long term entryid, do not use this!
 #define fnevLongTermEntryIDs ((ULONG) 0x20000000)
