@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -74,7 +74,10 @@
 #include <endian.h>
 #endif
 #include <errno.h>
+#include <locale.h>
 
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
 #include <string>
 
 #ifdef HAVE_UNISTD_H
@@ -102,6 +105,18 @@
 
 #define _vsnprintf vsnprintf
 #define _snprintf snprintf
+#ifdef HAVE_VSNPRINTF_L
+#define _vsnprintf_l vsnprintf_l
+#elif defined __OpenBSD__
+#define _vsnprintf_l vsnprintf
+#else
+inline int _vsnprintf_l(char *str, size_t size, const char *format, locale_t locale, va_list ap) {
+	locale_t prev = uselocale(locale);
+	int ret = _vsnprintf(str, size, format, ap);
+	uselocale(prev);
+	return ret;
+}
+#endif
 
 #include <sys/types.h>
 #include <sys/wait.h>
