@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -131,8 +131,8 @@ std::string shell_escape(std::string str);
 std::string shell_escape(std::wstring wstr);
 std::string forcealnum(const std::string& str, const char *additional = NULL);
 
-std::vector<std::wstring> tokenize(const std::wstring &strInput, const WCHAR sep);
-std::vector<std::string> tokenize(const std::string &strInput, const char sep);
+std::vector<std::wstring> tokenize(const std::wstring &strInput, const WCHAR sep, bool bFilterEmpty = false);
+std::vector<std::string> tokenize(const std::string &strInput, const char sep, bool bFilterEmpty = false);
 std::string concatenate(std::vector<std::string> &elements, const std::string &delimeters);
 
 std::string trim(const std::string &strInput, const std::string &strTrim = " ");
@@ -154,13 +154,15 @@ std::wstring bin2hexw(unsigned int inLength, const unsigned char *input);
 #endif
 
 std::string urlEncode(const std::string &input);
-std::wstring urlEncode(const std::wstring &input);
+std::string urlEncode(const std::wstring &input, const char* charset);
+std::string urlEncode(const WCHAR* input, const char* charset);
 std::string urlDecode(const std::string &input);
 
 std::string StringEscape(const char* input, const char *tokens, const char escape);
 
 void BufferLFtoCRLF(size_t size, const char *input, char *output, size_t *outsize);
 void StringCRLFtoLF(const std::wstring &strInput, std::wstring *lpstrOutput);
+void StringLFtoCRLF(std::string &strInOut);
 void StringTabtoSpaces(const std::wstring &strInput, std::wstring *lpstrOutput);
 
 template<typename T>
@@ -213,4 +215,5 @@ _Tp join(_InputIterator __first, _InputIterator __last, _Tp __sep)
     return s;
 }
 
+
 #endif
