@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -83,6 +83,9 @@ private:
 	pthread_mutex_t &m_mutex;
 };
 
+#define WITH_LOCK(_lock)	\
+	for (scoped_lock __lock(_lock), *ptr = NULL; ptr == NULL; ptr = &__lock)
+
 
 template<int(*fnlock)(pthread_rwlock_t*)>
 class scoped_rwlock {
