@@ -1275,6 +1275,7 @@ PR_EMS_AB_ROOM_DESCRIPTION = PROP_TAG(PT_STRING8, 0x0809)
 PR_EMS_AB_HOME_MDB = PROP_TAG(PT_STRING8, 0x8006)
 PR_EMS_AB_HOME_MTA = PROP_TAG(PT_STRING8, 0x8007)
 PR_EMSMDB_SECTION_UID = PROP_TAG(PT_BINARY, 0x3D15)
+PR_EMS_AB_CONTAINERID = PROP_TAG(PT_LONG, 0xFFFD)
 
 # Freebusy properties
 PR_FREEBUSY_START_RANGE = PROP_TAG(PT_LONG, 0x6847)
@@ -1358,15 +1359,18 @@ PR_EC_BASE 				= 0x6700
 
 PR_EC_PATH 				= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x00)
 PR_EC_USERNAME 			= PROP_TAG(PT_TSTRING, PR_EC_BASE + 0x01)
-PR_EC_USERNAME_A 			= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x01)
-PR_EC_USERNAME_W 			= PROP_TAG(PT_UNICODE, PR_EC_BASE + 0x01)
+PR_EC_USERNAME_A 		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x01)
+PR_EC_USERNAME_W 		= PROP_TAG(PT_UNICODE, PR_EC_BASE + 0x01)
 PR_EC_USERPASSWORD		= PROP_TAG(PT_TSTRING, PR_EC_BASE + 0x02)
-PR_EC_USERPASSWORD_A		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x02)
-PR_EC_USERPASSWORD_W		= PROP_TAG(PT_UNICODE, PR_EC_BASE + 0x02)
+PR_EC_USERPASSWORD_A	= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x02)
+PR_EC_USERPASSWORD_W	= PROP_TAG(PT_UNICODE, PR_EC_BASE + 0x02)
 PR_EC_PORT 				= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x03)
 PR_EC_FLAGS				= PROP_TAG(PT_LONG, PR_EC_BASE + 0x04)
 PR_EC_SSLKEY_FILE		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x05)
 PR_EC_SSLKEY_PASS		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x06)
+PR_EC_IMPERSONATEUSER	= PROP_TAG(PT_TSTRING, PR_EC_BASE+0x12)
+PR_EC_IMPERSONATEUSER_A	= PROP_TAG(PT_STRING8, PR_EC_BASE+0x12)
+PR_EC_IMPERSONATEUSER_W	= PROP_TAG(PT_UNICODE, PR_EC_BASE+0x12)
 
 PR_EC_HIERARCHYID       	= PROP_TAG(PT_LONG,               PR_EC_BASE+0x11)
 PR_EC_STOREGUID             = PROP_TAG(PT_BINARY,             PR_EC_BASE+0x12)
@@ -1386,18 +1390,40 @@ PR_EC_STATSTABLE_SYSTEM		= PROP_TAG(PT_OBJECT,		PR_EC_BASE+0x30)
 PR_EC_STATSTABLE_SESSIONS	= PROP_TAG(PT_OBJECT,		PR_EC_BASE+0x31)
 PR_EC_STATSTABLE_USERS		= PROP_TAG(PT_OBJECT,		PR_EC_BASE+0x32)
 PR_EC_STATSTABLE_COMPANY	= PROP_TAG(PT_OBJECT,		PR_EC_BASE+0x33)
+PR_EC_STATSTABLE_SERVERS	= PROP_TAG(PT_OBJECT,		PR_EC_BASE+0x34)
 
 # system stats
 PR_EC_STATS_SYSTEM_DESCRIPTION	= PROP_TAG(PT_TSTRING,		PR_EC_BASE+0x40)
 PR_EC_STATS_SYSTEM_VALUE	= PROP_TAG(PT_TSTRING,		PR_EC_BASE+0x41)
 
 # session stats
-PR_EC_STATS_SESSION_ID		= PROP_TAG(PT_LONGLONG,		PR_EC_BASE+0x42)
+PR_EC_STATS_SESSION_ID		= 	PROP_TAG(PT_LONGLONG,		PR_EC_BASE+0x42)
 PR_EC_STATS_SESSION_IPADDRESS	= PROP_TAG(PT_TSTRING,		PR_EC_BASE+0x43)
 PR_EC_STATS_SESSION_IDLETIME	= PROP_TAG(PT_LONG,		PR_EC_BASE+0x44)
 PR_EC_STATS_SESSION_CAPABILITY	= PROP_TAG(PT_LONG,		PR_EC_BASE+0x45)
-PR_EC_STATS_SESSION_LOCKED	= PROP_TAG(PT_BOOLEAN,		PR_EC_BASE+0x46)
+PR_EC_STATS_SESSION_LOCKED	= 	PROP_TAG(PT_BOOLEAN,		PR_EC_BASE+0x46)
 PR_EC_STATS_SESSION_BUSYSTATES	= PROP_TAG(PT_MV_TSTRING,	PR_EC_BASE+0x47)
+PR_EC_STATS_SESSION_PORT	= 	PROP_TAG(PT_LONG,               PR_EC_BASE+0x48)
+PR_EC_STATS_SESSION_URL     = 	PROP_TAG(PT_STRING8,    PR_EC_BASE+0x52)
+PR_EC_STATS_SESSION_PROXY   = 	PROP_TAG(PT_STRING8,    PR_EC_BASE+0x53)
+
+PR_EC_COMPANY_NAME =            PROP_TAG(PT_TSTRING,    PR_EC_BASE+0x48)
+PR_EC_COMPANY_NAME_A =          PROP_TAG(PT_STRING8,    PR_EC_BASE+0x48)
+PR_EC_COMPANY_NAME_W =          PROP_TAG(PT_UNICODE,    PR_EC_BASE+0x48)
+PR_EC_COMPANY_ADMIN =           PROP_TAG(PT_TSTRING,    PR_EC_BASE+0x49)
+PR_EC_COMPANY_ADMIN_A =         PROP_TAG(PT_STRING8,    PR_EC_BASE+0x49)
+PR_EC_COMPANY_ADMIN_W =         PROP_TAG(PT_UNICODE,    PR_EC_BASE+0x49)
+
+PR_EC_STATS_SERVER_NAME =		PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF0)
+PR_EC_STATS_SERVER_HOST	= 		PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF1)
+PR_EC_STATS_SERVER_HTTPPORT	=	PROP_TAG(PT_LONG,		PR_EC_BASE+0xF2)
+PR_EC_STATS_SERVER_SSLPORT =	PROP_TAG(PT_LONG,		PR_EC_BASE+0xF3)
+PR_EC_STATS_SERVER_FILEPATH	=	PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF4)
+PR_EC_STATS_SERVER_PROXYURL	=	PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF5)
+PR_EC_STATS_SERVER_HTTPURL =	PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF6)
+PR_EC_STATS_SERVER_HTTPSURL	=	PROP_TAG(PT_STRING8, 	PR_EC_BASE+0xF7)
+PR_EC_STATS_SERVER_FILEURL =	PROP_TAG(PT_STRING8,	PR_EC_BASE+0xF8)
+
 
 # IMAP Gateway special props
 PR_EC_IMAP_ID = 				PROP_TAG(PT_LONG,	PR_EC_BASE+0x82)
@@ -1437,6 +1463,8 @@ EC_PROFILE_FLAGS_NO_PUBLIC_STORE		= 0x0000004
 EC_PROFILE_FLAGS_OFFLINE				= 0x0000080
 EC_PROFILE_FLAGS_CACHE_PRIVATE			= 0x0000100
 EC_PROFILE_FLAGS_CACHE_PUBLIC			= 0x0000400
+EC_PROFILE_FLAGS_TRUNCATE_SOURCEKEY		= 0x0000800
+EC_PROFILE_FLAGS_NO_UID_AUTH			= 0x0001000
 
 # Flags for PurgeCache
 PURGE_CACHE_QUOTA			= 0x0001
@@ -1559,3 +1587,51 @@ IID_ECChangeAdviseSink = DEFINE_GUID(0xc6937b5a,0x48d7,0x4017,0xa0,0x41,0x25,0x6
 IID_IECImportContentsChanges = DEFINE_GUID(0x2458600a,0xf010,0x4ee4,0xb8,0xe1,0xbf,0xd7,0xc1,0xaa,0x1e,0xc5)
 IID_IECMessageRaw = DEFINE_GUID(0x54cd0028, 0x46e7, 0x4555, 0xb6, 0x8f, 0x1a, 0xe7, 0x9d, 0x61, 0x71, 0xc1)
 IID_IECLicense = DEFINE_GUID(0xa9a55c9a, 0xd2bb, 0x461e, 0x9f, 0xf5, 0xfd, 0x4e, 0xd9, 0x84, 0x4c, 0x2e)
+
+class ACTTYPE:
+    OP_MOVE = 1
+    OP_COPY = 2
+    OP_REPLY = 3
+    OP_OOF_REPLY = 4
+    OP_DEFER_ACTION = 5
+    OP_BOUNCE = 6
+    OP_FORWARD = 7
+    OP_DELEGATE = 8
+    OP_TAG = 9
+    OP_DELETE = 10
+    OP_MARK_AS_READ = 11
+
+EDK_RULES_VERSION               = 0x1
+
+ST_DISABLED                     = 0x0000
+ST_ENABLED                      = 0x0001
+ST_ERROR                        = 0x0002
+ST_ONLY_WHEN_OOF                = 0x0004
+ST_KEEP_OOF_HIST                = 0x0008
+ST_EXIT_LEVEL                   = 0x0010
+ST_SKIP_IF_SCL_IS_SAFE          = 0x0020
+ST_RULE_PARSE_ERROR             = 0x0040
+ST_CLEAR_OOF_HIST               = 0x80000000
+
+# Permissions
+ecRightsNone            = 0x00000000
+ecRightsReadAny         = 0x00000001
+ecRightsCreate          = 0x00000002
+ecRightsEditOwned       = 0x00000008
+ecRightsDeleteOwned     = 0x00000010
+ecRightsEditAny         = 0x00000020
+ecRightsDeleteAny       = 0x00000040
+ecRightsCreateSubfolder = 0x00000080
+ecRightsFolderAccess    = 0x00000100
+ecRightsFolderVisible   = 0x00000400
+ecRightsFullControl     = 0x00004FBL
+
+EMS_AB_ADDRESS_LOOKUP = 0x1
+
+SHOW_SOFT_DELETES	= 0x02
+DELETE_HARD_DELETE	= 0x10
+
+DTE_FLAG_REMOTE_VALID = 0x80000000
+DTE_FLAG_ACL_CAPABLE  = 0x40000000
+DTE_MASK_REMOTE       = 0x0000ff00
+DTE_MASK_LOCAL        = 0x000000ff
